This is a operating system made with Python.
"How is it made?"
It was made in Feburary 12, 2026.
"How can it break after entering shutdown?"
It can say "Shutting down CosmicOS." And "Goodbye!" And Then Breaks.
## Installation
```bash
pip install CosmicOS
```
## Usage
```python
import CosmicOS

CosmicOS.cosmic()
```
